@@ -434,7 +434,7 @@ public:
 		//done = isDone();
 	}
 
-	void step(int action) {
+	void stepAuto(int action) {
 		//assume default executor and chrono target
 		vector<int> viableExecutors = getViableExecutors(action);
 		if (action == n.chronoboost) {
@@ -747,6 +747,7 @@ PYBIND11_MODULE(probotest1, m) {
 		.def(pybind11::init<>())
 		.def(pybind11::init<const ProtossMacroEnv&>(), "constuctor 2", pybind11::arg("env"))
         .def("step", &ProtossMacroEnv::step)
+		.def("stepAuto", &ProtossMacroEnv::stepAuto)
 		.def("reset", &ProtossMacroEnv::reset)
 		.def("getEntityList", &ProtossMacroEnv::getState)
 		.def("getViableActions", &ProtossMacroEnv::getViableActions)
